package cn.com.qmth.dp.examcloud.oe.modules.fill_course_id;

import cn.com.qmth.dp.examcloud.oe.entity.question.PaperStruct;
import com.mongodb.client.result.UpdateResult;
import org.apache.commons.lang3.StringUtils;
import org.bson.types.ObjectId;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.data.mongodb.core.query.Update;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 题库试卷结构写入课程ID
 *
 * @author chenken
 */
@Service
public class FillCourseIdService {

    @Autowired
    MongoTemplate mongoTemplate;

    @Autowired
    private JdbcTemplate jdbcTemplate;

    public void start() {
        Date start = new Date();
        int updateCount = 0;

        //查找试卷
        List<PaperStruct> ps = mongoTemplate.findAll(PaperStruct.class);
        if (ps != null && ps.size() > 0) {
            System.out.println("总条数:" + ps.size());

            int index = 0;
            for (PaperStruct paper : ps) {
                if (paper.getCourseId() == null && StringUtils.isNotBlank(paper.getCourseNo())) {
                    Long courseId = queryCourseId(Long.valueOf(paper.getOrgId()), paper.getCourseNo());
                    updatePaperStruct(paper.getId(), courseId);
                    updateCount++;
                }

                index++;
                System.out.println(String.format("%s--> id:%s, rootOrgId:%s, courseCode:%s, courseId:%s",
                        index, paper.getId(), paper.getOrgId(), paper.getCourseNo(), paper.getCourseId()));
            }
        } else {
            System.out.println("总条数:0");
        }

        Date end = new Date();
        System.out.println("实际修改条数:" + updateCount);
        System.out.println("耗时:" + ((end.getTime() - start.getTime()) / (1000 * 60)) + "分钟");
    }

    public long updatePaperStruct(String id, Long courseId) {
        // 查询相应的题目
        Query query = Query.query(Criteria.where("_id").is(new ObjectId(id)));
        Update update = new Update();
        update.set("courseId", courseId);
        UpdateResult upResult = mongoTemplate.updateFirst(query, update, "paperStruct");
        long res = upResult.getMatchedCount();

        return res;
    }

    private Long queryCourseId(Long rootOrgId, String courseCode) {
        final String querySql = String.format("select id from ec_b_course where root_org_id = %s and code = '%s' ", rootOrgId, courseCode);
        return jdbcTemplate.queryForObject(querySql, Long.class);
    }

}
